var searchData=
[
  ['nc_5fcallback_5ferror_5freply',['nc_callback_error_reply',['../d0/de2/group__reply.html#ga771a110143440bcd3b7d4c0e98388e80',1,'callbacks.h']]],
  ['nc_5fcallback_5fprint',['nc_callback_print',['../d3/d35/group__gen_a_p_i.html#ga806dfa9c27d2b8076bae21bcd549cce7',1,'callbacks.h']]],
  ['nc_5fcallback_5fssh_5fhost_5fauthenticity_5fcheck',['nc_callback_ssh_host_authenticity_check',['../db/d52/group__session.html#ga78a69a69dea0369455218c5aeedce9f8',1,'callbacks_ssh.h']]],
  ['nc_5fcallback_5fsshauth_5finteractive',['nc_callback_sshauth_interactive',['../db/d52/group__session.html#ga41c10d3af57cccebc7c67b11e4024c21',1,'callbacks_ssh.h']]],
  ['nc_5fcallback_5fsshauth_5fpassphrase',['nc_callback_sshauth_passphrase',['../db/d52/group__session.html#ga81ef9b1c1949bbffd86cbfd9aa159726',1,'callbacks_ssh.h']]],
  ['nc_5fcallback_5fsshauth_5fpassword',['nc_callback_sshauth_password',['../db/d52/group__session.html#ga28299d575ef4e234ed96bad5c4f086fb',1,'callbacks_ssh.h']]],
  ['nc_5fcallhome_5faccept',['nc_callhome_accept',['../db/de7/group__callhome.html#ga556966a9c54e814e02b4afadf128b9b7',1,'callhome.h']]],
  ['nc_5fcallhome_5fconnect',['nc_callhome_connect',['../db/de7/group__callhome.html#ga5c1437b22b1ccac95d0ba15c34912f78',1,'callhome.h']]],
  ['nc_5fcallhome_5flisten',['nc_callhome_listen',['../db/de7/group__callhome.html#gafa8e04fb09dcafcd7c06d086e835f25f',1,'callhome.h']]],
  ['nc_5fcallhome_5flisten_5fstop',['nc_callhome_listen_stop',['../db/de7/group__callhome.html#ga93a36d2d6c0e1d1eb0c65d70c6ded3cc',1,'callhome.h']]],
  ['nc_5fcallhome_5fmngmt_5fserver_5fadd',['nc_callhome_mngmt_server_add',['../db/de7/group__callhome.html#gaa08ac6e90c2b70dd2461bab461f3ed08',1,'callhome.h']]],
  ['nc_5fcallhome_5fmngmt_5fserver_5ffree',['nc_callhome_mngmt_server_free',['../db/de7/group__callhome.html#ga3db211a665c56160c167619b633b6cb0',1,'callhome.h']]],
  ['nc_5fcallhome_5fmngmt_5fserver_5fgetactive',['nc_callhome_mngmt_server_getactive',['../db/de7/group__callhome.html#ga8b22e5afbc118e69b42b0f66388f56ab',1,'callhome.h']]],
  ['nc_5fcallhome_5fmngmt_5fserver_5frm',['nc_callhome_mngmt_server_rm',['../db/de7/group__callhome.html#ga1c2942e68d263d674adf1381bc5e7083',1,'callhome.h']]],
  ['nc_5fclose',['nc_close',['../d3/d35/group__gen_a_p_i.html#gaaf2f5bf5a58103d9e4ea1cbe4291094b',1,'netconf.h']]],
  ['nc_5fcpblts_5fadd',['nc_cpblts_add',['../db/d52/group__session.html#ga2ea9b318015206d886c7e54386fc85e3',1,'session.h']]],
  ['nc_5fcpblts_5fcount',['nc_cpblts_count',['../db/d52/group__session.html#ga79a7aea77cbfe29535eb83a6e5c60419',1,'session.h']]],
  ['nc_5fcpblts_5fenabled',['nc_cpblts_enabled',['../db/d52/group__session.html#gaa8325078c33d25a7cf48e1ed9d417ff4',1,'session.h']]],
  ['nc_5fcpblts_5ffree',['nc_cpblts_free',['../db/d52/group__session.html#ga6465c58b3ca057b46655d5ffa90caff3',1,'session.h']]],
  ['nc_5fcpblts_5fget',['nc_cpblts_get',['../db/d52/group__session.html#gabed55135f1868bef5f266737b8862aa4',1,'session.h']]],
  ['nc_5fcpblts_5fiter_5fnext',['nc_cpblts_iter_next',['../db/d52/group__session.html#gaea2ced8d4e5f2cc9971680e49f876c58',1,'session.h']]],
  ['nc_5fcpblts_5fiter_5fstart',['nc_cpblts_iter_start',['../db/d52/group__session.html#gae92c774e940114b4733f85e186d84620',1,'session.h']]],
  ['nc_5fcpblts_5fnew',['nc_cpblts_new',['../db/d52/group__session.html#gabdd04a64fd465ebbf910c6b08393ac43',1,'session.h']]],
  ['nc_5fcpblts_5fremove',['nc_cpblts_remove',['../db/d52/group__session.html#gacb59cf4fa78bf02c22afac395acf0693',1,'session.h']]],
  ['nc_5fdatetime2time',['nc_datetime2time',['../d3/d35/group__gen_a_p_i.html#ga4dfd796fda30d3ad8588b4c30c4c1583',1,'netconf.h']]],
  ['nc_5fdel_5fkeypair_5fpath',['nc_del_keypair_path',['../db/d52/group__session.html#ga93972e2d0602d0f3fd2728af279e61c1',1,'callbacks_ssh.h']]],
  ['nc_5ferr_5fdup',['nc_err_dup',['../d3/d35/group__gen_a_p_i.html#ga316faef1140f1b48a2ed1de6d84d2bef',1,'error.h']]],
  ['nc_5ferr_5ffree',['nc_err_free',['../d3/d35/group__gen_a_p_i.html#gac4bd51febe24b517d1952d1c1d8f6b07',1,'error.h']]],
  ['nc_5ferr_5fget',['nc_err_get',['../d3/d35/group__gen_a_p_i.html#ga3d7714f1f56ac7203a80c61aea4344f8',1,'error.h']]],
  ['nc_5ferr_5fnew',['nc_err_new',['../d3/d35/group__gen_a_p_i.html#ga057524ba5256c428b6bf88710f000e0c',1,'error.h']]],
  ['nc_5ferr_5fset',['nc_err_set',['../d3/d35/group__gen_a_p_i.html#gab28d881eeebd79d485391ae1ffc97299',1,'error.h']]],
  ['nc_5ffilter_5ffree',['nc_filter_free',['../db/de9/group__rpc.html#ga0dbfd598d6fd303819817370cdf63229',1,'messages.h']]],
  ['nc_5ffilter_5fnew',['nc_filter_new',['../db/de9/group__rpc.html#ga599c715b0aee0f1f2ed231ce1d78e5bd',1,'messages.h']]],
  ['nc_5finit',['nc_init',['../d3/d35/group__gen_a_p_i.html#ga40e32bd7c1404a76105b426219021cdc',1,'netconf.h']]],
  ['nc_5fmsgid_5fcompare',['nc_msgid_compare',['../d3/d35/group__gen_a_p_i.html#gae160a70158f957344eb3204987329632',1,'session.h']]],
  ['nc_5freply_5fbuild',['nc_reply_build',['../d0/de2/group__reply.html#ga78b032942cee08721d51ea97acff68b5',1,'messages.h']]],
  ['nc_5freply_5fdata',['nc_reply_data',['../d0/de2/group__reply.html#ga4543351c89208bb06fa895be334d59ad',1,'messages.h']]],
  ['nc_5freply_5fdata_5fns',['nc_reply_data_ns',['../d0/de2/group__reply.html#ga8c365a22efcaab4f1c29b3f51f254aea',1,'messages.h']]],
  ['nc_5freply_5fdump',['nc_reply_dump',['../d0/de2/group__reply.html#ga279c8b48bfdf590c15a043b7d385dfb8',1,'messages.h']]],
  ['nc_5freply_5fdup',['nc_reply_dup',['../d0/de2/group__reply.html#gaeb66eff28fdf195f564cb3d997d65b65',1,'messages.h']]],
  ['nc_5freply_5ferror',['nc_reply_error',['../d0/de2/group__reply.html#ga12fd89263289491b84398279e0e449fd',1,'messages.h']]],
  ['nc_5freply_5ferror_5fadd',['nc_reply_error_add',['../d0/de2/group__reply.html#gafb04a6695650d05a07b571ac1410a681',1,'messages.h']]],
  ['nc_5freply_5ffree',['nc_reply_free',['../d0/de2/group__reply.html#ga17aa9f38d7b75dec1a57b478b0b39710',1,'messages.h']]],
  ['nc_5freply_5fget_5fdata',['nc_reply_get_data',['../d0/de2/group__reply.html#gaac62fb3d427985311cf71a2c3ab8d424',1,'messages.h']]],
  ['nc_5freply_5fget_5fdata_5fns',['nc_reply_get_data_ns',['../d0/de2/group__reply.html#ga4a5c880080d3044f1564192cd3780534',1,'messages.h']]],
  ['nc_5freply_5fget_5ferrormsg',['nc_reply_get_errormsg',['../d0/de2/group__reply.html#ga121d66d8f7437d87a995b82187e7e7ff',1,'messages.h']]],
  ['nc_5freply_5fget_5fmsgid',['nc_reply_get_msgid',['../d0/de2/group__reply.html#gad6ed5b3e0b7d8fbeb81e80bc0a326d6c',1,'messages.h']]],
  ['nc_5freply_5fget_5ftype',['nc_reply_get_type',['../d0/de2/group__reply.html#gab12cdef82337060c425348dada7fe983',1,'messages.h']]],
  ['nc_5freply_5fmerge',['nc_reply_merge',['../d0/de2/group__reply.html#gab1f7b7f9be8153758e5b047fe70fd48d',1,'messages.h']]],
  ['nc_5freply_5fok',['nc_reply_ok',['../d0/de2/group__reply.html#ga047f565bb3671ec4016fef5461e8f67e',1,'messages.h']]],
  ['nc_5frpc_5fbuild',['nc_rpc_build',['../db/de9/group__rpc.html#ga5c4348c96b0d5e6a64f94dbbdeaf4100',1,'messages.h']]],
  ['nc_5frpc_5fcapability_5fattr',['nc_rpc_capability_attr',['../db/de9/group__rpc.html#ga14f5e170cbc9acd9a146eee2fb6b796f',1,'messages.h']]],
  ['nc_5frpc_5fcommit',['nc_rpc_commit',['../db/de9/group__rpc.html#ga7977ca8b562643607b3c846ed36bbb23',1,'messages.h']]],
  ['nc_5frpc_5fcopyconfig',['nc_rpc_copyconfig',['../db/de9/group__rpc.html#gaf7b76c1243dc218cf1dc8b17876e319c',1,'messages.h']]],
  ['nc_5frpc_5fdeleteconfig',['nc_rpc_deleteconfig',['../db/de9/group__rpc.html#gae1faa46f5048f21dc580d44836d848e8',1,'messages.h']]],
  ['nc_5frpc_5fdiscardchanges',['nc_rpc_discardchanges',['../db/de9/group__rpc.html#ga337ea7a9b006a79ee5ea615e9d9a5a6f',1,'messages.h']]],
  ['nc_5frpc_5fdump',['nc_rpc_dump',['../db/de9/group__rpc.html#ga3e840368c40be2ea4d5201edbd3adaca',1,'messages.h']]],
  ['nc_5frpc_5fdup',['nc_rpc_dup',['../db/de9/group__rpc.html#gadab3d916540f79dd2b168134758fe3d1',1,'messages.h']]],
  ['nc_5frpc_5feditconfig',['nc_rpc_editconfig',['../db/de9/group__rpc.html#gae704e312c7aa5e6385abd4989e79398c',1,'messages.h']]],
  ['nc_5frpc_5ffree',['nc_rpc_free',['../db/de9/group__rpc.html#ga4041bda37caa9eedb7a1e2534280f3df',1,'messages.h']]],
  ['nc_5frpc_5fgeneric',['nc_rpc_generic',['../db/de9/group__rpc.html#gaa9ad7fac41fdef0063c2e2793fb19efd',1,'messages.h']]],
  ['nc_5frpc_5fget',['nc_rpc_get',['../db/de9/group__rpc.html#ga6818afbecf7fedf78f620162de78b4fd',1,'messages.h']]],
  ['nc_5frpc_5fget_5fconfig',['nc_rpc_get_config',['../db/de9/group__rpc.html#ga05a10e0b6c89ac04426410f399b87257',1,'messages.h']]],
  ['nc_5frpc_5fget_5fdefop',['nc_rpc_get_defop',['../db/de9/group__rpc.html#gaf867eacee93e3596371415d028e62d29',1,'messages.h']]],
  ['nc_5frpc_5fget_5ferropt',['nc_rpc_get_erropt',['../db/de9/group__rpc.html#ga488f894b9fa4866326837a9ed0575e36',1,'messages.h']]],
  ['nc_5frpc_5fget_5ffilter',['nc_rpc_get_filter',['../db/de9/group__rpc.html#ga05705bba8345c15637bc54cf6b9a4b3d',1,'messages.h']]],
  ['nc_5frpc_5fget_5fmsgid',['nc_rpc_get_msgid',['../db/de9/group__rpc.html#gabc7eb11a4f2fdbe302a2430e00935c48',1,'messages.h']]],
  ['nc_5frpc_5fget_5fns',['nc_rpc_get_ns',['../db/de9/group__rpc.html#ga21ae2135af2588162112c13fb4095652',1,'messages.h']]],
  ['nc_5frpc_5fget_5fop',['nc_rpc_get_op',['../db/de9/group__rpc.html#gabf639574395456fb6f4bade36fb4babd',1,'messages.h']]],
  ['nc_5frpc_5fget_5fop_5fcontent',['nc_rpc_get_op_content',['../db/de9/group__rpc.html#gade3f111e7c7727d512313b4875fd8f50',1,'messages.h']]],
  ['nc_5frpc_5fget_5fop_5fname',['nc_rpc_get_op_name',['../db/de9/group__rpc.html#ga9796f2bc7841265d478891974eb610c6',1,'messages.h']]],
  ['nc_5frpc_5fget_5fop_5fnamespace',['nc_rpc_get_op_namespace',['../db/de9/group__rpc.html#ga0b5d7acbcc0429fac6d5e3b509609bd8',1,'messages.h']]],
  ['nc_5frpc_5fget_5fsource',['nc_rpc_get_source',['../db/de9/group__rpc.html#ga3fcf5083b04a294e935a2897c212065b',1,'messages.h']]],
  ['nc_5frpc_5fget_5ftarget',['nc_rpc_get_target',['../db/de9/group__rpc.html#gab240067d45d58c945cdfd61948751379',1,'messages.h']]],
  ['nc_5frpc_5fget_5ftestopt',['nc_rpc_get_testopt',['../db/de9/group__rpc.html#gab12fec9068d72fa6817f4a59a81e625e',1,'messages.h']]],
  ['nc_5frpc_5fget_5ftype',['nc_rpc_get_type',['../db/de9/group__rpc.html#gaa502fb30575000775b29a764101c1bef',1,'messages.h']]],
  ['nc_5frpc_5fgetconfig',['nc_rpc_getconfig',['../db/de9/group__rpc.html#ga4ae747c4c96e1d3621745e122091ba11',1,'messages.h']]],
  ['nc_5frpc_5fgetschema',['nc_rpc_getschema',['../db/de9/group__rpc.html#ga3b762dd881622eaa72b08c9b58d76a5e',1,'messages.h']]],
  ['nc_5frpc_5fkillsession',['nc_rpc_killsession',['../db/de9/group__rpc.html#gae9876e8d038eb81a376bd82a08c58b95',1,'messages.h']]],
  ['nc_5frpc_5flock',['nc_rpc_lock',['../db/de9/group__rpc.html#ga6a03d40e00fbe019a34541a55f3f4a31',1,'messages.h']]],
  ['nc_5frpc_5fsubscribe',['nc_rpc_subscribe',['../da/d54/group__notifications.html#gafda56cbfe02d24877d0740618aa2de98',1,'messages.h']]],
  ['nc_5frpc_5funlock',['nc_rpc_unlock',['../db/de9/group__rpc.html#gad843551f9d1ff8be6a118d026e8b995a',1,'messages.h']]],
  ['nc_5frpc_5fvalidate',['nc_rpc_validate',['../db/de9/group__rpc.html#ga14fa1c78362457a646d5d820206d5158',1,'messages.h']]],
  ['nc_5fsession_5faccept',['nc_session_accept',['../db/d52/group__session.html#gad0e758dfee764ae9c2a032e0151c6707',1,'transport.h']]],
  ['nc_5fsession_5faccept_5finout',['nc_session_accept_inout',['../db/d52/group__session.html#ga4d2da6dc354779dbd7a745147fa40457',1,'transport.h']]],
  ['nc_5fsession_5faccept_5flibssh_5fchannel',['nc_session_accept_libssh_channel',['../d1/da1/libnetconf__ssh_8h.html#a159471d23a8253670ae176615f16965b',1,'libnetconf_ssh.h']]],
  ['nc_5fsession_5faccept_5ftls',['nc_session_accept_tls',['../d5/d22/libnetconf__tls_8h.html#a9cc131efe272d1309653cb7cf445fa32',1,'libnetconf_tls.h']]],
  ['nc_5fsession_5faccept_5fusername',['nc_session_accept_username',['../db/d52/group__session.html#ga7ee207cac84fd5cd82419af41e14c06f',1,'transport.h']]],
  ['nc_5fsession_5fconnect',['nc_session_connect',['../db/d52/group__session.html#gae3858d998d19cb2fb700b15fdf602f23',1,'transport.h']]],
  ['nc_5fsession_5fconnect_5fchannel',['nc_session_connect_channel',['../db/d52/group__session.html#ga7d9e0f17bb4ca5b35c8343db59955060',1,'transport.h']]],
  ['nc_5fsession_5fconnect_5finout',['nc_session_connect_inout',['../db/d52/group__session.html#gacaf7b465963605a29f25c3a36df378a6',1,'transport.h']]],
  ['nc_5fsession_5fdummy',['nc_session_dummy',['../db/d52/group__session.html#ga3868d5331db61a5d3a4df3ff5fa33851',1,'session.h']]],
  ['nc_5fsession_5ffree',['nc_session_free',['../db/d52/group__session.html#gaa5994f45a7031dc931bdf4a3acebedee',1,'session.h']]],
  ['nc_5fsession_5fget_5fcpblts',['nc_session_get_cpblts',['../db/d52/group__session.html#ga09bdf1d9eacf9f53bf3f05557ffe0821',1,'session.h']]],
  ['nc_5fsession_5fget_5fcpblts_5fdefault',['nc_session_get_cpblts_default',['../db/d52/group__session.html#ga8283673aa18f079a89a437efb436a55a',1,'session.h']]],
  ['nc_5fsession_5fget_5feventfd',['nc_session_get_eventfd',['../db/d52/group__session.html#ga826890ed745633bc2d31a53971dada32',1,'session.h']]],
  ['nc_5fsession_5fget_5fhost',['nc_session_get_host',['../db/d52/group__session.html#ga6399681dfce6e139cc5707af25d20bb3',1,'session.h']]],
  ['nc_5fsession_5fget_5fid',['nc_session_get_id',['../db/d52/group__session.html#ga91012cb5ae50651916ee2239661d7603',1,'session.h']]],
  ['nc_5fsession_5fget_5fport',['nc_session_get_port',['../db/d52/group__session.html#ga09bec340611b4b99c8c1bfb2ef3992d6',1,'session.h']]],
  ['nc_5fsession_5fget_5fstatus',['nc_session_get_status',['../db/d52/group__session.html#gacebd018e30c3eeb0638bbb428a1741b4',1,'session.h']]],
  ['nc_5fsession_5fget_5ftransport',['nc_session_get_transport',['../db/d52/group__session.html#ga1eae5ae3f6460dcc849733f0965c133c',1,'session.h']]],
  ['nc_5fsession_5fget_5fuser',['nc_session_get_user',['../db/d52/group__session.html#gabdd090cbc50a8f7db58e5be8062296d6',1,'session.h']]],
  ['nc_5fsession_5fget_5fversion',['nc_session_get_version',['../db/d52/group__session.html#gac8ea61702127df024c037869feb72d97',1,'session.h']]],
  ['nc_5fsession_5fmonitor',['nc_session_monitor',['../db/d52/group__session.html#ga023c9c813c59588ab938108f3f063d41',1,'session.h']]],
  ['nc_5fsession_5fnotif_5fallowed',['nc_session_notif_allowed',['../db/d52/group__session.html#gafd3b69869e102a4625a5ffb490b4d70f',1,'session.h']]],
  ['nc_5fsession_5frecv_5fnotif',['nc_session_recv_notif',['../da/d54/group__notifications.html#gad7ffa424401e8004fb24f9f77f0bb5be',1,'session.h']]],
  ['nc_5fsession_5frecv_5freply',['nc_session_recv_reply',['../d0/de2/group__reply.html#ga1b8c8ca9516003938e8f647bd870beaa',1,'session.h']]],
  ['nc_5fsession_5frecv_5frpc',['nc_session_recv_rpc',['../db/de9/group__rpc.html#ga214fcc2c0095d56f4aa0d90c11da25fc',1,'session.h']]],
  ['nc_5fsession_5fsend_5fnotif',['nc_session_send_notif',['../da/d54/group__notifications.html#ga2a6cd8e0aaaaf4e1b84d3a498a2a710c',1,'session.h']]],
  ['nc_5fsession_5fsend_5frecv',['nc_session_send_recv',['../db/de9/group__rpc.html#ga27d3fe78769630932a18c726df4fe6e6',1,'session.h']]],
  ['nc_5fsession_5fsend_5freply',['nc_session_send_reply',['../d0/de2/group__reply.html#ga0b344811af933d80615f0874650938cc',1,'session.h']]],
  ['nc_5fsession_5fsend_5frpc',['nc_session_send_rpc',['../db/de9/group__rpc.html#gaeb0d93ea1b5ef0c22c9e5372425fb5c3',1,'session.h']]],
  ['nc_5fsession_5ftransport',['nc_session_transport',['../db/d52/group__session.html#ga6e125c035cdebae8c49ff962866c0806',1,'transport.h']]],
  ['nc_5fset_5fkeypair_5fpath',['nc_set_keypair_path',['../db/d52/group__session.html#gad067c538c9c44117a99cb0620e135108',1,'callbacks_ssh.h']]],
  ['nc_5fssh_5fpref',['nc_ssh_pref',['../db/d52/group__session.html#ga13119fdaa84544bf254bdb35ffdf83e0',1,'libnetconf_ssh.h']]],
  ['nc_5ftime2datetime',['nc_time2datetime',['../d3/d35/group__gen_a_p_i.html#ga90a44b60b04512fd0a3507ab35a1ccc4',1,'netconf.h']]],
  ['nc_5ftls_5fdestroy',['nc_tls_destroy',['../db/db4/group__tls.html#gacf3aed5cccac55d0548f46761707ece9',1,'libnetconf_tls.h']]],
  ['nc_5ftls_5finit',['nc_tls_init',['../db/db4/group__tls.html#gacbf946a826fa6c7c18a4e66d532b659f',1,'libnetconf_tls.h']]],
  ['nc_5furl_5fdisable',['nc_url_disable',['../d5/d7d/group__url.html#gadf6c3370da661ab29b0834086a0dfbfe',1,'url.h']]],
  ['nc_5furl_5fenable',['nc_url_enable',['../d5/d7d/group__url.html#gafd033a4d3cafcd3f6af307dacaa18e50',1,'url.h']]],
  ['nc_5furl_5fset_5fprotocols',['nc_url_set_protocols',['../d5/d7d/group__url.html#ga61d005676d5582665a473229fc2180f7',1,'url.h']]],
  ['nc_5fverb_5ferror',['nc_verb_error',['../d3/d35/group__gen_a_p_i.html#gabd4e3697f3a1fe6b5853e692ad20c2bb',1,'netconf.h']]],
  ['nc_5fverb_5fverbose',['nc_verb_verbose',['../d3/d35/group__gen_a_p_i.html#gae4f0d22fb274269c0259497abb702f5d',1,'netconf.h']]],
  ['nc_5fverb_5fwarning',['nc_verb_warning',['../d3/d35/group__gen_a_p_i.html#ga943a7c859f20bb1278964a7424762d8e',1,'netconf.h']]],
  ['nc_5fverbosity',['nc_verbosity',['../d3/d35/group__gen_a_p_i.html#gadd8fd7b3bb2e7cba580c9a4229fe02d7',1,'netconf.h']]],
  ['ncdflt_5fget_5fbasic_5fmode',['ncdflt_get_basic_mode',['../d1/df7/group__withdefaults.html#gab8fcb8a41ad1124d34d59e31166a3d24',1,'with_defaults.h']]],
  ['ncdflt_5fget_5fsupported',['ncdflt_get_supported',['../d1/df7/group__withdefaults.html#ga607415761ceb4c832a334e898f1ad8a6',1,'with_defaults.h']]],
  ['ncdflt_5frpc_5fget_5fwithdefaults',['ncdflt_rpc_get_withdefaults',['../d1/df7/group__withdefaults.html#gacdabc187c9ca8f1faa7d9016decf3561',1,'with_defaults.h']]],
  ['ncdflt_5fset_5fbasic_5fmode',['ncdflt_set_basic_mode',['../d1/df7/group__withdefaults.html#ga69f613716993c78f10032958929553f3',1,'with_defaults.h']]],
  ['ncdflt_5fset_5fsupported',['ncdflt_set_supported',['../d1/df7/group__withdefaults.html#gaacdfebb053cae501e72e32220305d55b',1,'with_defaults.h']]],
  ['ncds_5fadd_5faugment_5ftransapi',['ncds_add_augment_transapi',['../d8/d55/group__transapi.html#gacd42f4efcc256fa4ecdaa021f82d6d1f',1,'datastore.h']]],
  ['ncds_5fadd_5faugment_5ftransapi_5fstatic',['ncds_add_augment_transapi_static',['../d8/d55/group__transapi.html#ga7f6f5af711045d8598f283ec09b9167a',1,'datastore_xml.h']]],
  ['ncds_5fadd_5fmodel',['ncds_add_model',['../db/d67/group__store.html#ga145c9446fad8c350934c21ca86cbaf47',1,'datastore.h']]],
  ['ncds_5fadd_5fmodels_5fpath',['ncds_add_models_path',['../db/d67/group__store.html#ga93c65facb061f1048674343ac94a993b',1,'datastore.h']]],
  ['ncds_5fapply_5frpc2all',['ncds_apply_rpc2all',['../db/d67/group__store.html#ga6e6e979bd82e50913c82b4dc37cb8759',1,'datastore.h']]],
  ['ncds_5fbreak_5flocks',['ncds_break_locks',['../db/d67/group__store.html#ga4158273f1ae0332638cc9343097c9f0a',1,'datastore.h']]],
  ['ncds_5fconsolidate',['ncds_consolidate',['../db/d67/group__store.html#gab2a27448a52972db6807571590a5c6da',1,'datastore.h']]],
  ['ncds_5fcustom_5fset_5fdata',['ncds_custom_set_data',['../da/d64/group__customds.html#ga1e9518d8cc9023c7585fd4de15daa75b',1,'datastore_custom.h']]],
  ['ncds_5fdevice_5finit',['ncds_device_init',['../d9/db6/datastore_8h.html#a838c60661fb05e3a0fbe5aef5c64ff87',1,'datastore.h']]],
  ['ncds_5ffeature_5fdisable',['ncds_feature_disable',['../db/d67/group__store.html#ga11b6f6240911ddcc5e6b8cbb6d36fcc0',1,'datastore.h']]],
  ['ncds_5ffeature_5fenable',['ncds_feature_enable',['../db/d67/group__store.html#ga1171ba251d855a3c9abbc57e526739b2',1,'datastore.h']]],
  ['ncds_5ffeature_5fisenabled',['ncds_feature_isenabled',['../db/d67/group__store.html#gac3644177deaaf308bb2ca218be99ea85',1,'datastore.h']]],
  ['ncds_5ffeatures_5fdisableall',['ncds_features_disableall',['../db/d67/group__store.html#ga017491407c8d2c6f596d17e64eb10d84',1,'datastore.h']]],
  ['ncds_5ffeatures_5fenableall',['ncds_features_enableall',['../db/d67/group__store.html#ga3c65e57d684b25885d3ccbeb84e9f4d9',1,'datastore.h']]],
  ['ncds_5ffile_5fset_5fpath',['ncds_file_set_path',['../d0/d3b/group__fileds.html#gad48955dab497b1258d80019e542acb9b',1,'datastore.h']]],
  ['ncds_5ffree',['ncds_free',['../db/d67/group__store.html#ga77b479cc1496b0c3883bb0f6bfe46754',1,'datastore.h']]],
  ['ncds_5ffree2',['ncds_free2',['../db/d67/group__store.html#ga05e7f1ed8185b92a6dbf904172dba9d2',1,'datastore.h']]],
  ['ncds_5fget_5fmodel',['ncds_get_model',['../db/d67/group__store.html#ga414b75711e49e0e1eea10ae15c14287e',1,'datastore.h']]],
  ['ncds_5fget_5fmodel_5fpath',['ncds_get_model_path',['../db/d67/group__store.html#ga5ec9fea534bfd146019b7efb882648be',1,'datastore.h']]],
  ['ncds_5finit',['ncds_init',['../db/d67/group__store.html#gaabb1ae2c497726ad826fc6478f97e8ff',1,'datastore.h']]],
  ['ncds_5fmodel_5finfo',['ncds_model_info',['../db/d67/group__store.html#gac1073caa8c9a04a766ce320ea0817a5c',1,'datastore.h']]],
  ['ncds_5fnew',['ncds_new',['../db/d67/group__store.html#ga69009c5985f9eec3a6920f98a6a1a5e6',1,'datastore.h']]],
  ['ncds_5fnew2',['ncds_new2',['../db/d67/group__store.html#ga18655a18464191a4aab1ef0b7d8ba5df',1,'datastore_xml.h']]],
  ['ncds_5fnew_5ftransapi',['ncds_new_transapi',['../d8/d55/group__transapi.html#ga80e69b4cada8c35e5e358287e8af3d85',1,'datastore.h']]],
  ['ncds_5fnew_5ftransapi_5fstatic',['ncds_new_transapi_static',['../d8/d55/group__transapi.html#gaaf4e4daa7fa8be965ded41eb006a6713',1,'datastore_xml.h']]],
  ['ncds_5frollback',['ncds_rollback',['../db/d67/group__store.html#gabb9806e70f3399aed7da879095d9c64e',1,'datastore.h']]],
  ['ncds_5fset_5fvalidation',['ncds_set_validation',['../db/d67/group__store.html#ga4777c16043f5856c5a65bcd20b5ecc31',1,'datastore.h']]],
  ['ncds_5fset_5fvalidation2',['ncds_set_validation2',['../db/d67/group__store.html#ga31c6fa81cf4c62c32561c1047903477f',1,'datastore_xml.h']]],
  ['ncntf_5fdispatch_5freceive',['ncntf_dispatch_receive',['../da/d54/group__notifications.html#ga82da94949fd2d901c3abb2c82882346c',1,'notifications.h']]],
  ['ncntf_5fdispatch_5fsend',['ncntf_dispatch_send',['../da/d54/group__notifications.html#ga9a085479245b4da6e20fd89892cc7bc1',1,'notifications.h']]],
  ['ncntf_5fevent_5fnew',['ncntf_event_new',['../da/d54/group__notifications.html#ga9641deaca934bcd7ff66ac3ae60fc722',1,'notifications.h']]],
  ['ncntf_5fnotif_5fcreate',['ncntf_notif_create',['../da/d54/group__notifications.html#ga226e6acf872c57ca4de3847718cfaafe',1,'notifications.h']]],
  ['ncntf_5fnotif_5ffree',['ncntf_notif_free',['../da/d54/group__notifications.html#gabc56c72fca74236e9c96f694cf521b67',1,'notifications.h']]],
  ['ncntf_5fnotif_5fget_5fcontent',['ncntf_notif_get_content',['../da/d54/group__notifications.html#gadc78f4dd6440f4f1ac3ea12092946bd3',1,'notifications.h']]],
  ['ncntf_5fnotif_5fget_5ftime',['ncntf_notif_get_time',['../da/d54/group__notifications.html#gae00135a2cb85cb2d74d7f0b8b355ab47',1,'notifications.h']]],
  ['ncntf_5fnotif_5fget_5ftype',['ncntf_notif_get_type',['../da/d54/group__notifications.html#ga3f32038a98705a6dbb9d7038f67cbceb',1,'notifications.h']]],
  ['ncntf_5fsession_5fget_5factive_5fsubscription',['ncntf_session_get_active_subscription',['../da/d54/group__notifications.html#ga3c44d0f8b0ffe29050de73f2ac209a32',1,'notifications.h']]],
  ['ncntf_5fstatus',['ncntf_status',['../da/d54/group__notifications.html#ga8c116b8aae2fe13811ebbfd3ca6f1a44',1,'notifications.h']]],
  ['ncntf_5fstream_5fallow_5fevents',['ncntf_stream_allow_events',['../da/d54/group__notifications.html#ga05a14f949bbb781fd58a233b1d2fab33',1,'notifications.h']]],
  ['ncntf_5fstream_5finfo',['ncntf_stream_info',['../da/d54/group__notifications.html#gaff62ddbbd893faf50d3db3fa3b08c21f',1,'notifications.h']]],
  ['ncntf_5fstream_5fisavailable',['ncntf_stream_isavailable',['../da/d54/group__notifications.html#ga8958e791e810dd07b9121d78c870e8c5',1,'notifications.h']]],
  ['ncntf_5fstream_5fiter_5ffinish',['ncntf_stream_iter_finish',['../da/d54/group__notifications.html#ga1f45b88f42bd06a4518433f79c5999a3',1,'notifications.h']]],
  ['ncntf_5fstream_5fiter_5fnext',['ncntf_stream_iter_next',['../da/d54/group__notifications.html#gae9e1a02911f865bbc0f2b4e702b82ed7',1,'notifications.h']]],
  ['ncntf_5fstream_5fiter_5fstart',['ncntf_stream_iter_start',['../da/d54/group__notifications.html#ga999c0dc786381fe91f1158b76bcbdee9',1,'notifications.h']]],
  ['ncntf_5fstream_5flist',['ncntf_stream_list',['../da/d54/group__notifications.html#ga1f8e55f0f292f0514e844e7293e2b6b4',1,'notifications.h']]],
  ['ncntf_5fstream_5fnew',['ncntf_stream_new',['../da/d54/group__notifications.html#ga30691c17b09e98c56d39c9ebfaba1ded',1,'notifications.h']]],
  ['ncntf_5fsubscription_5fcheck',['ncntf_subscription_check',['../da/d54/group__notifications.html#gad1efe90aba028ffbb2b018b30f8e3a4b',1,'notifications.h']]],
  ['ncxml_5ffilter_5fnew',['ncxml_filter_new',['../d7/dda/group__rpc__xml.html#gac05e048345a6130490bdbdde8e52a845',1,'messages_xml.h']]],
  ['ncxml_5freply_5fbuild',['ncxml_reply_build',['../d8/d73/group__reply__xml.html#gaaaf53b5a839be6935059fdf2818a5a42',1,'messages_xml.h']]],
  ['ncxml_5freply_5fdata',['ncxml_reply_data',['../d8/d73/group__reply__xml.html#ga1ce60f5416d4f75586836c1429c37149',1,'messages_xml.h']]],
  ['ncxml_5freply_5fdata_5fns',['ncxml_reply_data_ns',['../d8/d73/group__reply__xml.html#ga3647f5a4bb6d8827a613a6b214d45581',1,'messages_xml.h']]],
  ['ncxml_5freply_5fdump',['ncxml_reply_dump',['../d8/d73/group__reply__xml.html#ga68ec8a0daf54f584339924bca5b5a682',1,'messages_xml.h']]],
  ['ncxml_5freply_5fget_5fdata',['ncxml_reply_get_data',['../d8/d73/group__reply__xml.html#ga7878bc6bc6b6d1ca002044d7edf85943',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fbuild',['ncxml_rpc_build',['../d7/dda/group__rpc__xml.html#gaa6bcfc7c3e217e1b64c63bd674af4d8e',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fcopyconfig',['ncxml_rpc_copyconfig',['../d7/dda/group__rpc__xml.html#gae7ab635ff3bb76089e372f3d22ebaf3c',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fdump',['ncxml_rpc_dump',['../d7/dda/group__rpc__xml.html#ga9f27fbe1879115a07d7b3ae8bf6be9e6',1,'messages_xml.h']]],
  ['ncxml_5frpc_5feditconfig',['ncxml_rpc_editconfig',['../d7/dda/group__rpc__xml.html#gaf75f595f932fa0f075d633015829a85c',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fgeneric',['ncxml_rpc_generic',['../d7/dda/group__rpc__xml.html#gaad5d888e8c4a07a5f59b31555f7413bb',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fget_5fconfig',['ncxml_rpc_get_config',['../d7/dda/group__rpc__xml.html#ga16f3dd2aaa13922eae37551179913b18',1,'messages_xml.h']]],
  ['ncxml_5frpc_5fget_5fop_5fcontent',['ncxml_rpc_get_op_content',['../d7/dda/group__rpc__xml.html#ga78cb3e4ae4050de932cb9e705316ce53',1,'messages_xml.h']]],
  ['ncxmlntf_5fevent_5fnew',['ncxmlntf_event_new',['../db/dae/group__notifications__xml.html#ga21824f1e804eed5f8907eefdd9d03a85',1,'notifications_xml.h']]],
  ['ncxmlntf_5fnotif_5fcreate',['ncxmlntf_notif_create',['../db/dae/group__notifications__xml.html#gae1d3152a18bb5d030f9d42d62658986c',1,'notifications_xml.h']]],
  ['ncxmlntf_5fnotif_5fget_5fcontent',['ncxmlntf_notif_get_content',['../db/dae/group__notifications__xml.html#ga26fc8f89287a14cc1da067d9aeb92fdf',1,'notifications_xml.h']]]
];
